@@ -2,10 +2,8 @@
 
 use strict;
 use warnings;
-
 use Sort::Flat;
 
-my @arr = qw(ABC def JKL ghi PQRS mno);
-
 $, = "\n";
-print sort @arr; print "\n";
+print sort qw(ABC def JKL ghi PQRS mno); 
+print "\n";
